Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ratelimiter ¶
type Ratelimiter struct {
// contains filtered or unexported fields
}
func (*Ratelimiter) Close ¶
func (rate *Ratelimiter) Close()
func (*Ratelimiter) Init ¶
func (rate *Ratelimiter) Init(spawner Spawner)
Init resets the limiter and starts its garbage-collection worker.
When spawner is non-nil, the worker is started through it so callers can observe the same lifecycle as other long-lived networking workers.
type RatelimiterEntry ¶
type RatelimiterEntry struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.